@@ -28,15 +28,8 @@
 #include <champlain/champlain.h>
 #include <champlain-gtk/champlain-gtk.h>
 #include <gconf/gconf-client.h>
-
-#ifdef USE_LIBLOCATION
-#include <location/location-gps-device.h>
-#include <location/location-gpsd-control.h>
-#else
 #include <geoclue/geoclue-master.h>
 #include <geoclue/geoclue-position.h>
-#endif /* USE_LIBLOCATION */
-
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
 
@@ -73,9 +66,6 @@ struct _EmerillonWindowPrivate
 
 static void     build_ui        (EmerillonWindow *self);
 
-
-#ifndef USE_LIBLOCATION
-
 static gboolean
 set_zoom_for_accuracy (EmerillonWindow *self,
                        GeoclueAccuracy *accuracy)
@@ -190,145 +180,6 @@ emerillon_window_init (EmerillonWindow *self)
     }
 }
 
-#else /* USE_LIBLOCATION */
-
-
-
-
-
-
-
-
-
-
-
-
-struct AppData
-{
-    LocationGPSDControl *control;
-    LocationGPSDevice *device;
-};
-
-struct AppData appdata;
-
-
-
-static void on_error(LocationGPSDControl *control, LocationGPSDControlError error, gpointer data)
-{ 
-  g_debug("location error: %d... quitting", error);
-  g_main_loop_quit((GMainLoop *) data);
-}
-
-static void on_stop(LocationGPSDControl *control, gpointer data)
-{
-  g_debug("quitting");
-  g_main_loop_quit((GMainLoop *) data);
-} 
-
-static gboolean start_location(gpointer data)
-{
-	location_gpsd_control_start((LocationGPSDControl *) data);
-	return FALSE;
-}
-
-static gboolean
-set_zoom_for_accuracy (EmerillonWindow *self,
-                       int *accuracy)
-{
-  //int accuracy_level;
-  gint zoom_level;
-
-  zoom_level = 14; // hardcode to the STREET accuracy for the time being, find out how to determine the actual accuracy
-  
-  g_object_set (self->priv->view, "zoom-level", zoom_level, NULL);
-
-  return TRUE;
-}
-
-static void
-position_changed_cb (LocationGPSDevice *device, EmerillonWindow *self)
-
-/*
-                     GeocluePosition *position,
-                     GeocluePositionFields fields,
-                     int timestamp,
-                     double latitude,
-                     double longitude,
-                     double altitude,
-                     GeoclueAccuracy *accuracy,
-                     GError *error,
-                     EmerillonWindow *self)                     
-*/
-
-{
-  int accuracy=0;
-  if (!device)
-		return;
-		
-	if (device->fix) {
-		if (device->fix->fields & LOCATION_GPS_DEVICE_LATLONG_SET) {
-			g_debug("lat = %f, long = %f", device->fix->latitude, device->fix->longitude);
-			//location_gpsd_control_stop((LocationGPSDControl *) data);
-            set_zoom_for_accuracy (self, &accuracy); // need to feed this something useful
-            champlain_view_center_on (self->priv->view, device->fix->latitude, device->fix->longitude);			
-		}
-	}
-
-}
-
-
-
-
-
-static void
-emerillon_window_init (EmerillonWindow *self)
-{
-  GdkGeometry geometry;
-  //GMainLoop *loop;
-
-  self->priv = EMERILLON_WINDOW_GET_PRIVATE (self);
-
-  /* GConf. */
-  self->priv->client = gconf_client_get_default ();
-
-  gconf_client_add_dir (self->priv->client, EMERILLON_CONF_DIR,
-      GCONF_CLIENT_PRELOAD_RECURSIVE, NULL);
-
-  /* Window setup. */
-  geometry.min_width = 400;
-  geometry.min_height = 350;
-  gtk_window_set_geometry_hints (GTK_WINDOW (self), GTK_WIDGET (self),
-      &geometry,GDK_HINT_MIN_SIZE);
-
-  gtk_window_set_default_size (GTK_WINDOW (self), 640, 450);
-
-  /* Current position. */
-  appdata.control = location_gpsd_control_get_default();
-  appdata.device = g_object_new(LOCATION_TYPE_GPS_DEVICE, NULL);
-
-  g_object_set(G_OBJECT(appdata.control),
-        "preferred-method", LOCATION_METHOD_USER_SELECTED,
-        "preferred-interval", LOCATION_INTERVAL_DEFAULT,
-        NULL);
-
-  //g_signal_connect(appdata.control, "error-verbose", G_CALLBACK(on_error), loop);
-  g_signal_connect(appdata.device, "changed", G_CALLBACK(position_changed_cb), self);
-  //g_signal_connect(appdata.control, "gpsd-stopped", G_CALLBACK(on_stop), loop);
-
-  g_idle_add(start_location, appdata.control);
-
-}
-
-
-
-
-
-
-
-#endif /* USE_LIBLOCATION */
-
-
-
 static void
 emerillon_window_dispose (GObject *object)
 {
@@ -485,16 +336,10 @@ static void
 cmd_quit (GtkAction *action,
           EmerillonWindow *self)
 {
-#ifdef USE_LIBLOCATION
-  location_gpsd_control_stop((LocationGPSDControl *) appdata.control);
-#endif /* USE_LIBLOCATION */
-
   gtk_widget_destroy (GTK_WIDGET (self));
   gtk_main_quit ();
 }
 
-
-
 static void
 cmd_help (GtkAction *action,
           EmerillonWindow *self)
@@ -630,6 +475,28 @@ cmd_show_hide_bar (GtkAction *action,
   gconf_client_set_bool (self->priv->client, target_conf_key, visible, NULL);
 }
 
+static void
+cmd_toggle_fullscreen (GtkAction *action,
+              EmerillonWindow *self)
+{
+  gboolean fullscreen;
+  GtkWidget *window;
+
+  fullscreen = gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action));
+  window = emerillon_window_dup_default ();
+
+  if (fullscreen)
+    {
+      gtk_window_fullscreen (GTK_WINDOW (window));
+    }
+  else
+    {
+      gtk_window_unfullscreen (GTK_WINDOW (window));
+    }
+
+  g_object_unref (window);
+}
+
 static void
 cmd_zoom_in (GtkAction *action,
              EmerillonWindow *self)
@@ -774,6 +641,9 @@ static const GtkToggleActionEntry toggle_entries[] = {
       { "ViewSidebar", NULL, N_("Side _Pane"), "F9",
         N_("Show or hide the side pane in the current window"),
         G_CALLBACK (cmd_show_hide_bar), TRUE },
+      { "ViewFullscreen", GTK_STOCK_FULLSCREEN, NULL, "F11",
+        N_("Enable or disable full screen mode"),
+        G_CALLBACK (cmd_toggle_fullscreen), FALSE },
 };
 
 static const GtkRadioActionEntry radio_entries[] = {
@@ -898,10 +768,15 @@ build_ui (EmerillonWindow *self)
   self->priv->view = gtk_champlain_embed_get_view (GTK_CHAMPLAIN_EMBED (embed_view));
   g_signal_connect (self->priv->view, "notify::zoom-level",
       G_CALLBACK (zoom_changed_cb), self);
+  g_signal_connect (self->priv->view, "notify::map-source",
+      G_CALLBACK (zoom_changed_cb), self);
   g_signal_connect (self->priv->view, "notify::state",
       G_CALLBACK (state_changed_cb), self);
   g_object_set (self->priv->view, "zoom-level", 1,
       "scroll-mode", CHAMPLAIN_SCROLL_MODE_KINETIC,
+#if CHAMPLAIN_CHECK_VERSION (0, 4, 3)
+      "show-scale", TRUE,
+#endif
       NULL);
   champlain_view_center_on (self->priv->view, 40, 0);
 
