@@ -154,7 +154,7 @@ result_cb (RestProxyCall *call,
         }
 
       lat = rest_xml_node_find (n, "lat");
-      if (!lon)
+      if (!lat)
         {
           n = n->next;
           continue;
@@ -202,6 +202,7 @@ result_cb (RestProxyCall *call,
 
       g_free (symbol);
       g_free (display_name);
+      g_free (escaped_name);
 
       n = n->next;
       i++;
@@ -279,7 +280,6 @@ search_activate_cb (GtkEntry *entry,
   search_address (plugin);
 }
 
-#if GTK_CHECK_VERSION(2,16,0) // make this a GTK version check.
 static void
 search_icon_activate_cb (GtkEntry *entry,
                          GtkEntryIconPosition position,
@@ -288,6 +288,46 @@ search_icon_activate_cb (GtkEntry *entry,
 {
   search_address (plugin);
 }
+
+#if CHAMPLAIN_CHECK_VERSION(0, 4, 1)
+static void
+marker_selected_cb (ChamplainSelectionLayer *layer,
+                    SearchPlugin *plugin)
+{
+  GtkTreeIter iter;
+  ChamplainBaseMarker *selected;
+  GtkTreeSelection *selection;
+  SearchPluginPrivate *priv = SEARCH_PLUGIN (plugin)->priv;
+
+  selected = champlain_selection_layer_get_selected (layer);
+
+  if (!selected)
+    return;
+
+  if (!gtk_tree_model_get_iter_first (priv->model, &iter))
+    return;
+
+  selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (priv->treeview));
+
+  do
+    {
+      ChamplainBaseMarker *marker;
+      gtk_tree_model_get (priv->model, &iter, COL_MARKER, &marker, -1);
+
+      if (!marker)
+        continue;
+
+      if (marker == selected)
+        {
+          gtk_tree_selection_select_iter (selection, &iter);
+          g_object_unref (marker);
+          return;
+        }
+
+      g_object_unref (marker);
+    }
+  while (gtk_tree_model_iter_next (priv->model, &iter));
+}
 #endif
 
 static void
@@ -295,22 +335,21 @@ row_selected_cb (GtkTreeSelection *selection,
                  SearchPlugin *plugin)
 {
   GtkTreeIter iter;
-  GValue value = {0};
   ChamplainBaseMarker *marker;
   SearchPluginPrivate *priv = SEARCH_PLUGIN (plugin)->priv;
 
   if (!gtk_tree_selection_get_selected (selection, &priv->model, &iter))
     return;
 
-  gtk_tree_model_get_value (priv->model, &iter, COL_MARKER, &value);
-  marker = g_value_get_object (&value);
-  g_value_unset (&value);
+  gtk_tree_model_get (priv->model, &iter, COL_MARKER, &marker, -1);
 
   if (!marker)
     return;
 
   champlain_selection_layer_select (CHAMPLAIN_SELECTION_LAYER (priv->layer),
         marker);
+
+  g_object_unref (marker);
 }
 
 static void
@@ -320,7 +359,6 @@ row_activated_cb (GtkTreeView *tree_view,
                   SearchPlugin *plugin)
 {
   GtkTreeIter iter;
-  GValue value = {0};
   gfloat lat, lon;
   ChamplainMarker *marker;
   SearchPluginPrivate *priv = SEARCH_PLUGIN (plugin)->priv;
@@ -328,25 +366,18 @@ row_activated_cb (GtkTreeView *tree_view,
   if (!gtk_tree_model_get_iter (priv->model, &iter, path))
     return;
 
-  gtk_tree_model_get_value (priv->model, &iter, COL_MARKER, &value);
-  marker = g_value_get_object (&value);
-  g_value_unset (&value);
+  gtk_tree_model_get (priv->model, &iter, COL_MARKER, &marker, -1);
 
   if (!marker)
     return;
 
-  gtk_tree_model_get_value (priv->model, &iter, COL_LAT, &value);
-  lat = g_value_get_float (&value);
-  g_value_unset (&value);
-
-  gtk_tree_model_get_value (priv->model, &iter, COL_LON, &value);
-  lon = g_value_get_float (&value);
-  g_value_unset (&value);
+  gtk_tree_model_get (priv->model, &iter, COL_LAT, &lat, COL_LON, &lon, -1);
 
   if (champlain_view_get_zoom_level (priv->map_view) < 12)
     champlain_view_set_zoom_level (priv->map_view, 12);
 
   champlain_view_center_on (priv->map_view, lat, lon);
+  g_object_unref (marker);
 }
 
 static gboolean
@@ -396,15 +427,12 @@ activated (EthosPlugin *plugin)
   priv->search_entry = gtk_entry_new ();
   g_signal_connect (priv->search_entry, "activate",
       G_CALLBACK (search_activate_cb), plugin);
-#if GTK_CHECK_VERSION(2,16,0) // make this a GTK version check.
   gtk_entry_set_icon_from_stock (GTK_ENTRY (priv->search_entry),
       GTK_ENTRY_ICON_SECONDARY, "gtk-find");
   gtk_entry_set_icon_activatable (GTK_ENTRY (priv->search_entry),
       GTK_ENTRY_ICON_SECONDARY, TRUE);
   g_signal_connect (priv->search_entry, "icon-press",
       G_CALLBACK (search_icon_activate_cb), plugin);
-#endif
-// no need for the above code as the icon won't be there, and enter should activate the entry anyway - se cb above.
 
   priv->search_item = gtk_tool_item_new ();
   gtk_tool_item_set_expand (GTK_TOOL_ITEM (priv->search_item), TRUE);
@@ -492,8 +520,14 @@ activated (EthosPlugin *plugin)
   priv->layer = champlain_selection_layer_new();
   champlain_view_add_layer (priv->map_view,
       priv->layer);
-  /* FIXME: when ChamplainSelectionLayer grows a selection-changed
-   * signal, connect to it */
+
+#if CHAMPLAIN_CHECK_VERSION(0, 4, 1)
+  g_signal_connect (priv->layer,
+                    "changed",
+                    G_CALLBACK (marker_selected_cb),
+                    plugin);
+#endif
+
   clutter_actor_show (CLUTTER_ACTOR (priv->layer));
 
   g_object_unref (window);
@@ -503,7 +537,7 @@ static void
 deactivated (EthosPlugin *plugin)
 {
   GtkWidget *window, *toolbar, *sidebar;
-  /* ChamplainView *view; */
+  ChamplainView *view;
   SearchPluginPrivate *priv = SEARCH_PLUGIN (plugin)->priv;
 
   if (priv->proxy)
@@ -527,10 +561,11 @@ deactivated (EthosPlugin *plugin)
   window = emerillon_window_dup_default ();
   toolbar = emerillon_window_get_toolbar (EMERILLON_WINDOW (window));
   sidebar = emerillon_window_get_sidebar (EMERILLON_WINDOW (window));
-  /* view = emerillon_window_get_map_view (EMERILLON_WINDOW (window));
-   * FIXME: when libchamplain grows a remove_layer, use it!
-   */
+  view = emerillon_window_get_map_view (EMERILLON_WINDOW (window));
 
+#if CHAMPLAIN_CHECK_VERSION(0, 4, 1)
+  champlain_view_remove_layer (view, priv->layer);
+#endif
 
   gtk_container_remove (GTK_CONTAINER (toolbar), GTK_WIDGET (priv->search_item));
   emerillon_sidebar_remove_page (EMERILLON_SIDEBAR (sidebar), priv->search_page);
